from pydantic import BaseModel
from typing import Literal, Optional, List

class EntityMatch(BaseModel):
    values: Optional[List[str]] = None
    mode: Literal["whitelist", "blacklist"]
    entity_type: str



from dataclasses import Field
from pydantic import confloat, BaseModel
from typing import Literal, Optional, Dict, List, Annotated, Any
from .base_scanner import Scanner, ScannerResult
from ..utils.entity_match import EntityMatch

class Anonymize(Scanner):
    """
        For all available tags, check: https://docs.testsavant.ai/docs/v1/python/input-scanners
    """
    threshold: Optional[confloat(ge=0.0, le=1.0)] = None
    use_faker: Optional[bool] = False
    tag: Literal["base"]
    result: Optional[ScannerResult] = None
    redact: bool = False
    entities: List[EntityMatch]





from typing import Literal, Optional
from ..input_scanners.base_scanner import Scanner, ScannerResult

class LLM(Scanner):
    """
        For all available tags, check: https://docs.testsavant.ai/docs/v1/python/input-scanners
    """
    tag: Literal["default"] = "default"
    instruction: str
    result: Optional[ScannerResult] = None
    num_retry: Optional[int] = None



from pydantic import confloat
from typing import Literal, Optional
from .base_scanner import Scanner, ScannerResult

class TokenLimit(Scanner):
    """
        For all available tags, check: https://docs.testsavant.ai/docs/v1/python/input-scanners
    """
    tag: Literal["default"] = "default"
    limit: Optional[int] = None
    result: Optional[ScannerResult] = None